@@ -29,6 +29,26 @@ sub distribution {
     return $self->{distribution};
 }
 
+sub meta_merge {
+    return {
+	'meta-spec'	=> {
+	    version	=> 2,
+	},
+	no_index	=> {
+	    directory	=> [ qw{ inc t xt } ],
+	},
+	resources	=> {
+	    bugtracker	=> 'https://rt.cpan.org/Public/Dist/Display.html?Name=Encode-RAD50',
+	    license	=> 'http://dev.perl.org/licenses/',
+	    repository	=> {
+		type	=> 'git',
+		url	=> 'git://github.com/trwyant/perl-Encode-RAD50.git',
+		web	=> 'https://github.com/trwyant/perl-Encode-RAD50',
+	    },
+	}
+    };
+}
+
 sub requires {
     my ( $self, @extra ) = @_;
 ##  if ( ! $self->distribution() ) {
@@ -104,6 +124,16 @@ C<< {META_MERGE}->{build_requires} >> or C<BUILD_REQUIRES> key.
 This method returns the value of the environment variable
 C<MAKING_MODULE_DISTRIBUTION> at the time the object was instantiated.
 
+=head2 meta_merge
+
+ use YAML;
+ print Dump( $meta->meta_merge() );
+
+This method returns a reference to a hash describing the meta-data which
+has to be provided by making use of the builder's C<meta_merge>
+functionality. This includes the C<dynamic_config>, C<no_index> and
+C<resources> data.
+
 =head2 requires
 
  use YAML;
@@ -148,7 +178,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2014 by Thomas R. Wyant, III
+Copyright (C) 2010-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
